API Reference
=============

.. py:currentmodule:: multihash

.. autofunction:: encode

.. autofunction:: decode

.. autofunction:: is_valid

.. autofunction:: is_valid_code

.. autofunction:: get_prefix

.. autofunction:: coerce_code

.. autofunction:: is_app_code

.. autofunction:: to_hex_string

.. autofunction:: from_hex_string

.. autofunction:: to_b58_string

.. autofunction:: from_b58_string

.. autoclass:: Multihash
